@@ -25,92 +25,79 @@ class DescribeGroupedMaliciousFilesRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'DescribeGroupedMaliciousFiles')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_RepoId(self):
+	def get_RepoId(self): # String
 		return self.get_query_params().get('RepoId')
 
-	def set_RepoId(self,RepoId):
-		self.add_query_param('RepoId',RepoId)
-
-	def get_FuzzyMaliciousName(self):
+	def set_RepoId(self, RepoId):  # String
+		self.add_query_param('RepoId', RepoId)
+	def get_FuzzyMaliciousName(self): # String
 		return self.get_query_params().get('FuzzyMaliciousName')
 
-	def set_FuzzyMaliciousName(self,FuzzyMaliciousName):
-		self.add_query_param('FuzzyMaliciousName',FuzzyMaliciousName)
-
-	def get_RepoNamespace(self):
+	def set_FuzzyMaliciousName(self, FuzzyMaliciousName):  # String
+		self.add_query_param('FuzzyMaliciousName', FuzzyMaliciousName)
+	def get_RepoNamespace(self): # String
 		return self.get_query_params().get('RepoNamespace')
 
-	def set_RepoNamespace(self,RepoNamespace):
-		self.add_query_param('RepoNamespace',RepoNamespace)
-
-	def get_ImageDigest(self):
+	def set_RepoNamespace(self, RepoNamespace):  # String
+		self.add_query_param('RepoNamespace', RepoNamespace)
+	def get_ImageDigest(self): # String
 		return self.get_query_params().get('ImageDigest')
 
-	def set_ImageDigest(self,ImageDigest):
-		self.add_query_param('ImageDigest',ImageDigest)
-
-	def get_PageSize(self):
+	def set_ImageDigest(self, ImageDigest):  # String
+		self.add_query_param('ImageDigest', ImageDigest)
+	def get_PageSize(self): # String
 		return self.get_query_params().get('PageSize')
 
-	def set_PageSize(self,PageSize):
-		self.add_query_param('PageSize',PageSize)
-
-	def get_Lang(self):
+	def set_PageSize(self, PageSize):  # String
+		self.add_query_param('PageSize', PageSize)
+	def get_Lang(self): # String
 		return self.get_query_params().get('Lang')
 
-	def set_Lang(self,Lang):
-		self.add_query_param('Lang',Lang)
-
-	def get_ImageTag(self):
+	def set_Lang(self, Lang):  # String
+		self.add_query_param('Lang', Lang)
+	def get_ImageTag(self): # String
 		return self.get_query_params().get('ImageTag')
 
-	def set_ImageTag(self,ImageTag):
-		self.add_query_param('ImageTag',ImageTag)
-
-	def get_CurrentPage(self):
+	def set_ImageTag(self, ImageTag):  # String
+		self.add_query_param('ImageTag', ImageTag)
+	def get_CurrentPage(self): # Integer
 		return self.get_query_params().get('CurrentPage')
 
-	def set_CurrentPage(self,CurrentPage):
-		self.add_query_param('CurrentPage',CurrentPage)
-
-	def get_ClusterId(self):
+	def set_CurrentPage(self, CurrentPage):  # Integer
+		self.add_query_param('CurrentPage', CurrentPage)
+	def get_ClusterId(self): # String
 		return self.get_query_params().get('ClusterId')
 
-	def set_ClusterId(self,ClusterId):
-		self.add_query_param('ClusterId',ClusterId)
-
-	def get_RepoName(self):
+	def set_ClusterId(self, ClusterId):  # String
+		self.add_query_param('ClusterId', ClusterId)
+	def get_RepoName(self): # String
 		return self.get_query_params().get('RepoName')
 
-	def set_RepoName(self,RepoName):
-		self.add_query_param('RepoName',RepoName)
-
-	def get_RepoInstanceId(self):
+	def set_RepoName(self, RepoName):  # String
+		self.add_query_param('RepoName', RepoName)
+	def get_RepoInstanceId(self): # String
 		return self.get_query_params().get('RepoInstanceId')
 
-	def set_RepoInstanceId(self,RepoInstanceId):
-		self.add_query_param('RepoInstanceId',RepoInstanceId)
-
-	def get_ImageLayer(self):
+	def set_RepoInstanceId(self, RepoInstanceId):  # String
+		self.add_query_param('RepoInstanceId', RepoInstanceId)
+	def get_ImageLayer(self): # String
 		return self.get_query_params().get('ImageLayer')
 
-	def set_ImageLayer(self,ImageLayer):
-		self.add_query_param('ImageLayer',ImageLayer)
-
-	def get_Levels(self):
+	def set_ImageLayer(self, ImageLayer):  # String
+		self.add_query_param('ImageLayer', ImageLayer)
+	def get_Levels(self): # String
 		return self.get_query_params().get('Levels')
 
-	def set_Levels(self,Levels):
-		self.add_query_param('Levels',Levels)
-
-	def get_RepoRegionId(self):
+	def set_Levels(self, Levels):  # String
+		self.add_query_param('Levels', Levels)
+	def get_RepoRegionId(self): # String
 		return self.get_query_params().get('RepoRegionId')
 
-	def set_RepoRegionId(self,RepoRegionId):
-		self.add_query_param('RepoRegionId',RepoRegionId)
\ No newline at end of file
+	def set_RepoRegionId(self, RepoRegionId):  # String
+		self.add_query_param('RepoRegionId', RepoRegionId)
