@@ -25,14 +25,14 @@ class UnbindAegisRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'UnbindAegis')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_Uuids(self):
+	def get_Uuids(self): # String
 		return self.get_query_params().get('Uuids')
 
-	def set_Uuids(self,Uuids):
-		self.add_query_param('Uuids',Uuids)
\ No newline at end of file
+	def set_Uuids(self, Uuids):  # String
+		self.add_query_param('Uuids', Uuids)
